Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1904)

Unified Diff: chrome/browser/resources/options2/content_settings_exceptions_area.js

Issue 10537099: add "always allow" option to the mediastream infobar and allow user to allow/not allow acces to devi (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebased, addressed comments from Ivan, let "block" apply before exceptions Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/options2/content_settings_exceptions_area.js
diff --git a/chrome/browser/resources/options2/content_settings_exceptions_area.js b/chrome/browser/resources/options2/content_settings_exceptions_area.js
index 17bc9b7392e8104aa2e338af05c77fc82e7341d3..13f93646d85d07bb93576f32f9702d6302df5c1c 100644
--- a/chrome/browser/resources/options2/content_settings_exceptions_area.js
+++ b/chrome/browser/resources/options2/content_settings_exceptions_area.js
@@ -111,9 +111,10 @@ cr.define('options.contentSettings', function() {
this.updateEditables();
// Editing notifications and geolocation is disabled for now.
if (this.contentType == 'notifications' ||
- this.contentType == 'location') {
+ this.contentType == 'location' ||
+ this.contentType == 'mediastream') {
Evan Stade 2012/06/15 18:51:25 why isn't fullscreen in this list?
no longer working on chromium 2012/06/15 21:04:47 Not sure, shall we add it?
Evan Stade 2012/06/15 21:33:32 could you find whoever added it to the list down b
no longer working on chromium 2012/06/18 10:22:49 I will ping the guy.
this.editable = false;
}
@@ -442,10 +443,11 @@ cr.define('options.contentSettings', function() {
* Returns whether the rows are editable in this list.
*/
isEditable: function() {
- // Editing notifications and geolocation is disabled for now.
+ // Exceptions of the following lists are not editable for now.
return !(this.contentType == 'notifications' ||
this.contentType == 'location' ||
- this.contentType == 'fullscreen');
+ this.contentType == 'fullscreen' ||
+ this.contentType == 'mediastream');
},
/**
@@ -111,9 +111,10 @@ cr.define('options.contentSettings', function() {
this.updateEditables();
- // Editing notifications and geolocation is disabled for now.
+ // Editing notifications, geolocation and mediastream is disabled for now.
if (this.contentType == 'notifications' ||

Powered by Google App Engine
This is Rietveld 408576698